export interface ComponentDefinition<T extends Object = {}> {
    name: string;
    renderFunction: React.FC<ComponentProps<T>>;
}
export interface ComponentProps<T extends Object = {}> {
    key?: string;
    path?: string;
    parameters?: {
        [key: string]: string;
    };
    internal?: {
        [key: string]: any | undefined;
    };
    settings: T;
    isVisible?: boolean;
}
export interface FullscreenComponentProps extends ComponentProps {
    absoluteFullscreen?: boolean;
    absoluteFullscreenStyle?: FullscreenStyle;
}
export interface FullscreenStyle {
    desktop?: React.CSSProperties;
    mobile?: React.CSSProperties;
}
export interface ComponentChangeProps {
    isBlocked?: boolean;
    callback?: () => void;
}
export interface Modal {
    title?: string | JSX.Element;
    text?: string | JSX.Element;
    reject?: boolean | string;
    accept?: boolean | string;
    rejectByIcon?: boolean;
    actions?: {
        text: string;
        id: string;
        variant?: 'outlined' | 'contained';
        closeable?: boolean;
    }[];
    dontRenderForm?: boolean;
    callback?: (accepted: boolean | FormData | string) => void;
    content?: React.ReactElement | string;
    iFrame?: string;
    progress?: number;
    image?: string;
    maxWidth?: number | string;
    width?: number | string;
    height?: number | string;
    fullscreen?: boolean | 'mobile';
    doNotAcceptOnEnter?: boolean;
}
export interface ClassicSnackBar {
    type: 'classic';
    /**
     * The action to display. It renders after the message, at the end of the snackbar.
     */
    action?: React.ReactNode;
    /**
     * The message to display.
     */
    message?: React.ReactNode;
    /**
     * milliseconds to wait before automatically closing
     */
    autoHideDuration?: number;
}
export interface BigSnackBar {
    type: 'big';
    /**
     * It renders a QR-Code for the provided link above the message
     */
    qrCode?: string;
    /**
     * size in pixels of the qr code. default 256
     */
    qrCodeSize?: number;
    /**
     * The message to display.
     */
    message?: React.ReactNode;
    /**
     * milliseconds to wait before automatically closing
     */
    autoHideDuration?: number;
    /**
     * Click on the qr-code opens the link in a new tab
     */
    clickable?: true;
}
export type SnackBar = ClassicSnackBar | BigSnackBar;
export interface Fullscreen {
    content: React.ReactElement;
    hideClose?: boolean;
    onClose?: () => void;
    absoluteFullscreen?: boolean;
    overwrittenZIndex?: number;
    hideSpinner?: boolean;
}
export interface SideMenu {
    listenToRightSwipe?: boolean;
    content: JSX.Element | React.ReactElement | 'RequestProductForm';
    side: 'left' | 'right';
    swipeable?: boolean;
    onClose?: () => void;
    open?: boolean;
    title?: string;
    showCoreHeader?: boolean;
    backgroundColor?: string;
    style?: React.CSSProperties;
    onSubmit?: (data: any) => void;
}
export type BarrierType = 'SIMPLE' | 'NO_LOGIN' | 'GET_EMAIL';
export interface Barrier {
    title?: string | JSX.Element;
    text?: string | JSX.Element;
    type?: BarrierType;
    rejectable?: boolean;
    anonOnly?: boolean;
    onClose?: () => void;
    actions?: BarrierAction[];
}
export interface HeaderInfos {
    visible: boolean;
    HeaderElement?: HTMLDivElement;
    onlyBurgerVisibles?: boolean;
}
export interface BarrierAction {
    text: string;
    loginType?: BarrierType;
    className?: string;
    onClick: (email: string) => void;
}
export type BannerType = 'INFO' | 'WARNING' | 'ERROR';
export interface Banner {
    key: string;
    type?: BannerType;
    title: string;
    text?: string;
    autoHideInSeconds?: number;
    hideClose?: boolean;
    useLocalStorage?: boolean;
    onClose?: () => void;
}
export interface LocalStorageBannerValue {
    valuekey?: string;
    userid?: string;
    expireTimestamp: number;
}
interface SendProps {
    variant?: string;
    to: string;
    cc?: string;
    domain?: string;
    language?: string;
}
export interface SendEmailProps extends SendProps {
    data?: any;
    type: 'other';
    kind: string;
}
export interface SendOrderProps extends SendProps {
    type: 'basket';
    data?: any;
    divaNr: string;
    version?: string | number;
}
export type EmailContent = SendEmailProps | SendOrderProps;
export type EmailData = {
    dialogText?: string;
    showDialog?: boolean;
    callback?: (success: boolean) => void;
    content: EmailContent;
};
export interface Theme {
    palette?: {
        primary?: {
            main: string;
            light: string;
            dark: string;
            contrastText: string;
        };
        secondary?: {
            main: string;
            light: string;
            dark: string;
            contrastText: string;
        };
        text?: {
            primary: string;
            secondary: string;
        };
    };
    typography?: {
        fontFamily: string;
    };
    components?: any;
}
export interface External {
    url: string;
    openInNewTab?: boolean;
    enableCorsCommunication?: boolean;
}
export interface Component {
    type?: string;
    identifier?: string;
    route?: string;
    parameters?: {
        [param: string]: string | undefined;
    };
    internal?: {
        [key: string]: any | undefined;
    };
    openInNewTab?: boolean | string;
    openInFullscreen?: boolean;
    absoluteFullscreen?: boolean;
    absoluteFullscreenStyle?: FullscreenStyle;
    keepOldState?: boolean;
}
export type Action = (Component & {
    breadcrumb?: boolean;
}) | External;
export interface ReplaceBreadcrumbs {
    type: 'replace';
    groupId: string;
    list: (AddBreadcrumbsParam & {
        level: number;
    })[];
}
export interface UpdateBreadcrumbs {
    type: 'update';
    param: AddBreadcrumbsParam;
}
export interface AddBreadcrumbsParam {
    groupId: string;
    level?: number;
    name: string;
    component: Component;
}
export type BreadcrumbParams = ReplaceBreadcrumbs | UpdateBreadcrumbs;
export type Event = {
    type: string;
    data?: any;
};
export interface OrganizationInfo {
    id: string;
    displayName: string;
}
export interface ApiConfig {
    analyticsService: string;
    authService: string;
    adminService: string;
    messageService: string;
    catalogService: string;
    supportService: string;
    mediaService: string;
    basketService: string;
    reportService: string;
    idmService: string;
    enricherService: string;
    clientArticleService?: string;
    constructorService: string;
    baseUrl: string;
    baseCdnUrl: string;
    host3d: string;
    diva3darchive: string;
    useDebugUrl?: boolean;
    api2: {
        default: string;
        ek: string;
        web: string;
    };
    baseSirvUrls?: string[];
    arViewerBaseUrl?: string;
    diva6BaseUrl?: string;
}
export interface Dimensions {
    isPortrait: boolean;
    isMobile: boolean;
    isTablet: boolean;
    width: number;
    height: number;
}
export type LoginMode = 'offline' | 'mixed' | 'online';
export interface FilterObject {
    id: string;
    value: any;
    op: string;
    or?: string;
}
export interface OrganizationData {
    _id: string;
    logoUrl?: string;
    internalId?: string;
    street: string;
    city: string;
    region: string;
    zipCode: string;
    countryCode: string;
    phone: string;
    email: string;
    originEnvironmentUrl?: string;
    parent?: string;
    typeParent?: string;
    defaultCatalog?: {
        catalogId: string;
        catalogCodex: string;
        accountId: string;
    };
    parentOrganizations?: {
        _id: string;
        displayName: string;
        parentType?: string;
        type?: string;
        crossOrganizationSetting?: 'YES' | 'NO';
        shopType: string;
    }[];
    childOrganizations?: string[];
    type?: 'SUPPLIER' | 'RETAILER' | 'ASSOCIATION';
    parentType?: 'SUPPLIER' | 'RETAILER' | 'ASSOCIATION';
    settings: {
        defaultCurrency: string;
        useCatalogTranslations: string;
        calcEkPriceForProducts?: boolean;
        hidePrices?: 'DEFAULT_VISIBLE' | 'DEFAULT_HIDDEN' | 'ONLY_VISIBLE' | 'ONLY_HIDDEN';
        pricePreview?: 'fromBasePrice' | 'fromCurrentPrice' | 'fromCurrentPriceHideCurrent' | 'off';
        languages?: string[];
        invitationType?: 'OTP' | 'STANDARD';
        wwsClient?: string;
        enable3DExport?: boolean;
        enableVKMarketing?: boolean;
        renderjobSeparateMaterials?: boolean;
        sendOrders?: boolean;
        sendOrdersEmail?: string;
    };
    api2Location?: {
        ek?: {
            url: string;
        };
        vk?: {
            url: string;
        };
        web?: {
            url: string;
        };
    };
    shopBaseUrl?: string;
    shareBaseUrl?: string;
    iwoFurnOptions?: IwoFurnOptions;
    hasIwoFurn?: boolean;
    displayName: string;
    description?: string;
    memberOf?: string[];
    accessAllOrganizations?: boolean;
    shopType?: string;
}
export interface IwoFurnOptions {
    iwofurnUsername?: string;
    pwdHash?: string;
    iwofurnSenderGLN?: string;
    iwofurnRecipientGLN?: string;
    sendIWOBasketEKPriceType?: string;
    iwoFurnWWS?: 'MHS' | 'ECORO' | 'WINMAX' | 'SHD';
}
export interface UserData {
    familyName?: string;
    name: string;
    birthdate?: number;
    gender?: string;
    locale?: string;
    picture?: string;
    pictureRefId?: string;
    mainEmail: string;
    phoneNumber?: string;
    isActive?: boolean;
    personalNumber?: string;
    isEmailVerified?: boolean;
    created: number;
    lastUpdated: number;
    createdBy: string;
    lastUpdatedBy: string;
    _id: string;
    cometChatAuthToken?: string;
}
export type UserRole = 'V' | 'E';
export {};
//# sourceMappingURL=externalTypes.d.ts.map