import { Action, Breadcrumb, BreadcrumbParams, Breadcrumbs, Component, ComponentConfiguration, ComponentDefinition, ComponentProps, EmailData, Modal, HeaderInfos } from '../types';
import RootStore from './RootStore';
import { Banner, Barrier as BarrierType, ComponentChangeProps, Dimensions, Fullscreen, FullscreenComponentProps, SideMenu, SnackBar } from '../externalTypes';
export default class ContentStore {
    private root;
    private configuration;
    private state;
    private _modelViewerHasLoaded;
    private _fullscreenComponent?;
    private _isAbsoluteComponent;
    private _modal?;
    private _snackBars;
    private _banner?;
    private _fullscreen?;
    private _sideMenu?;
    private _headerInfos;
    private visible?;
    private customLogoMap;
    private customHeaderComponentMap;
    private _breadcrumbs;
    private _hidePrices?;
    private _hideConfigPricePreview?;
    private _hideSnow?;
    private _componentChange?;
    private _restrictedComponent?;
    private ref?;
    private resizeObserver?;
    private _dimensions?;
    private _currentlyRendered;
    constructor(components: ComponentDefinition[], root: RootStore);
    loadModelViewer(): Promise<void>;
    resolveComponent(action: Action): string;
    /**
     * Open a component or an external url.
     *
     * Checks against the configuration and opens in the expected way (e.g. new tab)
     * @param action the component or external url
     */
    openComponent(action: Action): Generator<never, void, unknown>;
    openComponentInFullscreen(component: Component): Generator<Promise<any>, void, {
        [key: string]: any;
    } | undefined>;
    closeComponentInFullscreen(): void;
    /**
     * this flag is for components that by their own go in absoulte fullscrennmode like eg: PDP.
     * this flag influences the dimension calculation
     * @param val new state
     */
    setAbsoluteFullScreen(val: boolean): void;
    getSubConfiguration(type: string): any;
    private findSubComponent;
    private loginBarrier;
    private mapTypeToModule;
    /**
     * Update the custom logo for a list of components
     * @param components the list of components
     * @param logo the custom logo
     */
    updateCustomLogo(components: string[], logo?: string): void;
    /**
     * Update the custom headerelement for a list of components
     * @param components the list of components
     * @param element the custom header element
     */
    updateCustomHeaderElement(components: string[], element?: any): void;
    /**
     * Updates the breadcrumbs
     * If type is 'replace' a whole breadcrumb group gets replaces,
     * if the type is 'update' the group gets updated
     * @param params the update parameters for the breadcrumbs
     */
    updateBreadcrumbs(params: BreadcrumbParams): void;
    /**
     * Returns the current breadcrumbs the be rendered in the header
     */
    get breadcrumbs(): Breadcrumbs | undefined;
    /**
     * Initialize the breadcrumb array
     * @param breadcrumbs the inital value
     */
    initBreadcrumbs(breadcrumbs: Breadcrumb): void;
    /**
     * Returns the custom logo that should be added to the logos in the header, if there is any
     */
    get customLogo(): string | undefined;
    /**
     * Retruns the custom component that should be rendered in the header, if there is any
     */
    get customHeaderComponent(): any;
    /**
     * Returns the component setting of the current component
     */
    get currentComponent(): ComponentConfiguration | undefined;
    /**
     * Returns the currently stored restricted component if there is one
     */
    get restrictedComponent(): Component | undefined;
    set restrictedComponent(val: Component | undefined);
    /**
     * States the status of the footer
     */
    get showFooter(): boolean | "hidden";
    /**
     * States the current status for the hide Price button
     */
    get allowHidePrices(): boolean;
    /**
     * States if the prices should be hidden in the currently visible component
     * It gets the info from the current organization
     * when _hidePrices is undefined we use the default from the config in org
     */
    get hidePrices(): boolean;
    get hideConfigPricePreview(): boolean;
    /**
     * Hides or shows prices
     */
    toggleHidePrices(): void;
    /**
     * Hides or shows price preview in planner
     */
    toggleHideConfigPricePreview(): void;
    get hideSnow(): boolean;
    /**
     * Hides or shows snow
     */
    toggleHideSnow(): void;
    /**
     * States if the change of a component is blocked or not
     */
    get componentChange(): ComponentChangeProps | undefined;
    /**
     * Block Component change
     */
    setComponentChange(value: ComponentChangeProps): void;
    /**
     * Opens a modal
     * @param modal the settings for new modal
     */
    openModal(modal: Modal): void;
    /**
     * Resets the modal state
     */
    closeModal(): void;
    /**
     * The settings for a modal, if one should be opened
     */
    get modal(): Modal | undefined;
    openSnackBar(bar: SnackBar): string;
    closeSnackBar(key: string): void;
    get snackBars(): {
        key: string;
        data: SnackBar;
    }[];
    /**
     * Open full screen modal
     * @param fullscreen the settings for the fullscreen
     */
    openFullscreen(fullscreen: Fullscreen): void;
    /**
     * Resets the modal state
     */
    closeFullscreen(): void;
    /**
     * The settings of the fullscreen, if one should be opened
     */
    get fullscreen(): Fullscreen | undefined;
    closeBanner(): void;
    get banner(): Banner | undefined;
    /**
     * Open sideMenu screen modal
     * @param sideMenu the settings for the sideMenu
     */
    openSideMenu({ onClose, ...sideMenu }: SideMenu): void;
    /**
     * Resets the modal state
     */
    closeSideMenu(): void;
    /**
     * Updates HeaderInfos so other component know the state of the header
     */
    updateHeaderInfos(headerInfos: HeaderInfos): void;
    get headerInfos(): HeaderInfos;
    /**
     * The settings of the sideMenu, if one should be opened
     */
    get sideMenu(): SideMenu | undefined;
    /**
     * Opens a berrier to request user infos
     *
     * @param barrier the settings for the barrier
     */
    openBarrier(barrier: BarrierType): void;
    openBanner(banner: Banner): void;
    bannerInLocalStorage(banner: Banner): boolean;
    /**
     * Sends an email and if specified opens an input dialog before sending
     */
    sendEmail({ dialogText, showDialog, callback, content }: EmailData): Generator<Promise<any>, void, unknown>;
    /**
     * Retruns the current state of the named component
     * @param type
     */
    getState(type: string): ComponentProps;
    /**
     * Returns true of the named component should be visible
     * @param type the
     */
    isVisible(type: string): boolean;
    /**
     * Set the container ref, inorder to monitor the size
     * @param ref the current container
     */
    setContainer(ref: HTMLDivElement): Promise<void>;
    private isPublic;
    /**
     * A list of all component settings that are currently available, based on the configuration and user permissions
     */
    get availableComponents(): ComponentConfiguration[];
    /**
     * All components that should be loaded, with there renderfunction
     */
    get components(): any[];
    /**
     * All components that should be loaded, with there renderfunction
     */
    get fullscreenComponent(): {
        name: string;
        component: any;
        state: FullscreenComponentProps;
    };
    get isFullscreenComponentDefined(): boolean;
    get isAbsoluteFullscreenComponent(): boolean;
    /**
     * A list of all component types that are currently available, based on the configuration and user permissions
     */
    get availableComponentList(): string[];
    /**
     * The available buttons for the navigationbar, based on the configuration an user permissions
     */
    get availableButtons(): import("../types").Button[];
    /**
     * The material-ui theme based on the ccurrent configuration
     */
    get materialUiTheme(): import("@mui/material/styles").Theme;
    /**
     * Get the dimensions of the containing div (not the screen)
     */
    get containerDimensions(): Dimensions;
    /**
     * Reset the state of the page, i.e. on organization data change
     * Remove all cached component states and reopen the current component
     */
    resetState(): void;
    /**
     * Sets the theme as css variables
     */
    updateCssThemeVariables(): void;
    /**
     * Updates the component state if the user is logged out.
     * Deletes states and changes the currently visible component if it is not public
     */
    private updateStateAfterLogout;
    private resoveUrl;
    /**
     * Opens a component or an external url in a new tab
     *
     * @param action the action settings
     * @param baseUrl optional the base url for a component
     */
    private openInNewTab;
    /**
     * Gets the material-ui language object
     *
     * @param lang the language string
     */
    private getLang;
    /**
     * Callback for the resizeObserver
     * @param entries all registered entries
     */
    private onResize;
    private setGlobalClass;
}
//# sourceMappingURL=ContentStore.d.ts.map