import React from 'react';
import { ProductHandler, LoginMode } from '..';
import { ApiConfig, Barrier, Dimensions, Fullscreen, Theme, SideMenu, HeaderInfos, SnackBar, ComponentChangeProps } from '../externalTypes';
import { OrganizationHandler } from '../handler/OrganizationHandler';
import { MediaHandler } from '../handler/MediaHandler';
import { ReportHandler } from '../handler/ReportHandler';
import { AuthorizationHandler } from '../handler/AuthorizationHandler';
import { ClientArticleHandler } from '../handler/ClientArticleHandler';
import { Action, BreadcrumbParams, Component, ComponentDefinition, Modal, NavigationConfiguration, Event, EmailData, ApiConfigConfig, OrganizationData, UserData, UserRole, GoogleMapsConfig, CometChatConfig } from '../types';
import RootStore from './RootStore';
import { AdminHandler } from '../handler/AdminHandler';
import { AnalyticsHandler } from '../handler/AnalyticsHandler';
import { SupportHandler } from '../handler/SupportHandler';
export interface DivaCoreState {
    /**
     * Contains the current state
     */
    state: State;
    /**
     * Contains all action functions
     */
    actions: Actions;
    handler: CoreHandlers;
}
export interface State {
    /**
     * An array of all available component types
     */
    availableComponents: string[];
    /**
     * An array of all avialable languages
     */
    availableLanguages: string[];
    /**
     * The currently loaded organization
     */
    organization: OrganizationData;
    /**
     * The ordered list of the current organization and its parents
     */
    organizationHierarchy: {
        _id: string;
        displayName: string;
        type?: string;
    }[];
    /**
     * The currently logged in user
     */
    user?: UserData;
    /**
     * The JWT of the currently logged in user
     */
    jwt?: string;
    /**
     * The token used to authenticate the user
     */
    nToken?: string;
    /**
     * The configuration for the navigationbar
     */
    navigationConfiguration: NavigationConfiguration;
    /**
     * True if the application is currently initializing
     */
    initializing: boolean;
    /**
     * True if the loading spinner is currently vissible
     */
    loading: boolean;
    /**
     * Specifies if the prices should be displayed or not
     */
    hidePrices: boolean;
    /**
     * Specifies if the additional prices should be displayed or not in planner
     */
    hideConfigPricePreview: boolean;
    /**
     * Snow (winterspecial animation) is hidden or not
     */
    hideSnow: boolean;
    /**
     * The current dimensions of the containing div
     */
    dimensions: Dimensions;
    isMobile: boolean;
    isFirefox: boolean;
    /**
     * The current state of the navigator
     */
    headerInfos: HeaderInfos;
    /**
     * Contains the location of all services
     */
    apiConfig: ApiConfig;
    /**
     * The current theme of the application
     */
    theme: Theme;
    /**
     * The current LoginMode of the application
     */
    loginMode: LoginMode;
    /**
     * The context in which the application is running
     */
    applicationEnvironment: 'SELLER' | 'WEB';
    /**
     * there is currently a fullscreen component active
     */
    isFullscreenComponent: boolean;
    /**
     * there is supportservice enabled
     */
    enableSupport: boolean;
    /**
     * config for google maps
     */
    googleMapsConfig?: GoogleMapsConfig;
    /**
     * comet chat config params
     */
    cometChatConfig?: CometChatConfig;
    /**
     * defaultComponent
     */
    defaultComponent?: Component;
    /**
     * currentComponent
     */
    currentComponent?: Component;
    /**
     * componentChange
     */
    componentChange?: ComponentChangeProps;
}
export interface Actions {
    /**
     * Opens a new component or an external URL
     *
     * It takes care of the component/url should be opened in a new tab and if it is blocked by the browser
     */
    openComponent: (data: Action) => Promise<void>;
    /**
     * Opens a component in Fullscreen
     */
    closeComponentInFullscreen: () => void;
    /**
     * Sets flag for dimension calculation to use absoulte window size
     */
    setAbsoluteFullScreen: (val: boolean) => void;
    /**
     * Updates or replaces the breadcrumbs
     */
    updateBreadcrumbs: (params: BreadcrumbParams) => void;
    /**
     * Opens a new modal
     */
    openModal: (data: Modal) => void;
    /**
     * Closes a currently open modal
     */
    closeModal: () => void;
    /**
     * Send an email and optionally opens an input dialog before sending
     */
    sendEmail: (data: EmailData) => void;
    /**
     * Adds a custom logo to a list of components
     */
    updateCustomLogo: (components: string[], logo?: string) => void;
    /**
     * Adds a custom header element to a list of components
     */
    updateCustomHeaderElement: (components: string[], element?: any) => void;
    /**
     * Toggles the hide prices flag
     *
     * In case "allowHidePrices" is set to "hidden" or "false" for the component, this function has no effect
     */
    toggleHidePrices: () => void;
    /**
     * Toggles the hide additional prices flag
     */
    toggleHideConfigPricePreview: () => void;
    /**
     * Toggles the hide snowflakes
     *
     */
    toggleHideSnow: () => void;
    /**
     * Toggles the loading spinner
     *
     * Only after loading is set to "false" for all IDs, the spinner will be closed
     *
     * @param id an arbitrary ID for the current loading process
     * @param hidden if the component should be hidden during the loading process
     * @param toggle set explizitly if the spinner should be activated or deactivated
     */
    toggleLoading: (id: string, hidden?: boolean, toggle?: boolean) => void;
    /**
     * Load Model-Viewer
     */
    loadModelViewer: () => void;
    /**
     * Update the current language
     */
    changeLanguage: (lang: string) => void;
    /**
     * Update the current userMode
     */
    changeLoginMode: (loginMode: LoginMode) => void;
    /**
     * Send an event to a handler outside of diva
     */
    onEvent: (event: Event) => void;
    /**
     * Subscribe an event handler for events from outside of diva
     */
    subscribeEvents: (fn: (event: Event) => void) => void;
    /**
     * Unsubscribe an event handler for events from outside of diva
     */
    unSubscribeEvents: (fn: (event: Event) => void) => void;
    /**
     * Update the current organization
     */
    setOrganization: (organizationId: string) => void;
    /**
     * returns the sessionGuid for the API2. Is async because if not already loaded it make a loginByAuthToken
     */
    getSessionGuid: (userRole: UserRole, loginMode?: LoginMode, organizationId?: string, api2Location?: string) => Promise<string>;
    /**
     * returns the AuthLogin object for the API2.
     */
    getApi2AuthLoginData: (userRole: UserRole, loginMode?: LoginMode, organizationId?: string, api2Location?: string) => Promise<any>;
    /**
     * Logout the current user
     */
    logout: () => void;
    /**
     * Open the login window
     *
     * If the user is already logged in, this function has no effect
     */
    showLoginWindow: () => void;
    /**
     * Checks if the user has a certain permission
     */
    userHasPermission: (permission: string) => boolean;
    /**
     * Open a fullscreen window
     */
    openFullscreen: (fullscreen: Fullscreen) => void;
    /**
     * Close a fullscreen window
     */
    closeFullscreen: () => void;
    /**
     * Open the SideMenu
     */
    openSideMenu: (sideMenu: SideMenu) => void;
    /**
     * Close the SideMenu
     */
    closeSideMenu: () => void;
    /**
     * Open a barrier to request user infos
     */
    openBarrier: (barrier: Barrier) => void;
    /**
     * Updates HeaderInfos so other component know the state of the header
     */
    updateHeaderInfos: (headerInfos: HeaderInfos) => void;
    /**
     * Open a banner to show infos
     */
    openBanner: (banner: any) => void;
    closeBanner: () => void;
    /**
     * converts a action object to an url
     * @param action
     * @returns url
     */
    resolveComponent: (action: Action) => string;
    openSnackBar: (data: SnackBar) => void;
    setComponentChange: (value: ComponentChangeProps) => void;
    /**
     * Fetches configuration
     */
    fetchConfiguration: ({ identifier, type, domain, organizationId, }: {
        identifier?: string;
        domain?: string;
        type: string;
        organizationId?: string;
    }) => any;
    /**
     * Fetches a sub configuration of the current component
     */
    getSubConfiguration: (type: string) => any;
}
export interface CoreHandlers {
    productHandler: ProductHandler;
    organizationHandler: OrganizationHandler;
    mediaHandler: MediaHandler;
    adminHandler: AdminHandler;
    analyticsHandler: AnalyticsHandler;
    reportHandler: ReportHandler;
    supportHandler: SupportHandler;
    authorizationHandler: AuthorizationHandler;
    clientArticleHandler: ClientArticleHandler;
}
export declare const coreContext: React.Context<{
    store?: RootStore;
    context: DivaCoreState;
} | null>;
export interface DivaCoreProps {
    components: ComponentDefinition<any>[];
    currentComponent?: Component;
    /**
     * @deprecated
     */
    configUrl?: string;
    defaultApiConfig?: Partial<ApiConfigConfig>;
    spinnerClass?: string;
    language?: string;
    organizationId?: string;
    domain?: string;
    identifier?: string;
    telemetry?: boolean;
    onEvent?: (event: Event) => void;
}
export declare const DivaCoreProvider: React.ForwardRefExoticComponent<DivaCoreProps & {
    children: React.ReactElement;
} & React.RefAttributes<{
    invoke: (event: Event) => void;
}>>;
export declare const useDivaCoreContext: () => RootStore;
export declare const useDivaCore: () => DivaCoreState;
//# sourceMappingURL=index.d.ts.map